pub struct InodeTracker { /* private fields */ }Expand description
Tracks seen inodes to prevent double-counting hardlinks.
When a file has multiple hardlinks, we only want to count its size once. This tracker uses a concurrent set to track (inode, device) pairs.
Implementations
Sourceimpl InodeTracker
impl InodeTracker
Sourcepub fn track(&self, info: InodeInfo) -> bool
pub fn track(&self, info: InodeInfo) -> bool
Track an inode. Returns true if this is the first time seeing it.
If the inode was already tracked, returns false indicating this
is a hardlink to an already-counted file.